@@ -31,7 +31,7 @@ import uuid
 
 from datetime import datetime
 from pprint import pp
-from periodic import Periodic
+# from periodic import Periodic
 
 
 class UMF_Message:
@@ -294,8 +294,11 @@ class HydraPy:
             'uptimeSeconds': time.time() - psutil.boot_time()
         }
 
+    def get_redis_client(self):
+        return self._redis
+
     def _safe_json_stringify(self, umf_message):
-        json.dumps(umf_message, separators=(',', ':'))
+        return json.dumps(umf_message, separators=(',', ':'))
 
     async def send_message(self, umf_message):
         parsed_route = UMF_Message.parse_route(umf_message['to'])
@@ -458,7 +461,7 @@ class HydraPy:
         }))
 
     async def register_queue_handler(self, queue_handler):
-        return self._queue_handler = queue_handler
+        self._queue_handler = queue_handler
 
     async def queue_message(self, message):
         ''' self._service_name isn't used here because any service can queue '''
@@ -508,6 +511,8 @@ class HydraPy:
             await self._health_check_event()
         if self._queue_handler:
             await self._queue_handler()
+        await asyncio.sleep(self._ONE_SECOND)
+        await self._hydra_events()
 
     async def init(self):
         self._instance_id = uuid.uuid4().hex
@@ -517,8 +522,9 @@ class HydraPy:
         self._redis = await aioredis.create_redis_pool(redis_url, encoding='utf-8')
 
         await self._register_service()
-        p = Periodic(self._PRESENCE_UPDATE_INTERVAL, self._hydra_events)
-        await p.start()
+        await self._hydra_events()
+        # p = Periodic(self._PRESENCE_UPDATE_INTERVAL, self._hydra_events)
+        # await p.start()
 
         # TODO: determine best way to close
         # self._redis.close()
